@@ -9,8 +9,8 @@ fn main() {
     let config: Config = Config::new();
 
     options.free_living = true;
-    // options.gene_internal = true;
-    // options.species_internal = true;
+    options.gene_internal = true;
+    options.species_internal = true;
 
 
     let mut sp_tree: ArenaTree<String> = ArenaTree::default();
