@@ -158,6 +158,20 @@ pub fn draw_tree (
     svg::save(name, &document).unwrap();
 }
 
+
+pub fn get_longest_x_mul(gene_trees:&mut std::vec::Vec<ArenaTree<String>>) -> f32 {
+    let mut max = 0.0;
+    for tree in gene_trees {
+        let gene_max = tree.get_largest_x();
+        if gene_max > max {
+            max = gene_max;
+        }
+    }
+    max
+}
+
+
+
 pub fn get_longest_name_mul(gene_trees:&mut std::vec::Vec<ArenaTree<String>>) -> usize {
     let mut max = 0;
     for tree in gene_trees {
@@ -186,11 +200,15 @@ pub fn draw_sptree_gntrees (
     config: &Config,                                    // svg configuration
     transfers: &std::vec::Vec<(String,String)>          // additional transfers
     ) {
-    let largest_x = sp_tree.get_largest_x() * 1.0 + 0.0 ;
+    let mut largest_x = sp_tree.get_largest_x() * 1.0 + 0.0 ;
+    let largest_x_genes = get_longest_x_mul(gene_trees);//Gestion des genes free living qio peuvent depasser de l'arbre d'espece
+    if  largest_x_genes > largest_x {
+        largest_x = largest_x_genes;
+    }
     let largest_y = sp_tree.get_largest_y() * 1.0 + 0.0 ;
     let smallest_x = sp_tree.get_smallest_x() * 1.0 + 0.0 ;
     let smallest_y = sp_tree.get_smallest_y() * 1.0 + 0.0 ;
-    let width_svg = largest_x - smallest_x+ 1.0 * BLOCK;
+    let width_svg = largest_x - smallest_x + 1.0 * BLOCK;
     let width_svg = width_svg * 1.0;
     let mut longest_name = get_longest_name_mul(gene_trees) as f32;
     let species_longest_name = get_longest_name(sp_tree) as f32;
@@ -208,11 +226,11 @@ pub fn draw_sptree_gntrees (
                 .set("width",height_svg  )
                 .set("height",width_svg  )
                 .set("viewBox", (x_viewbox,y_viewbox,
-                    height_svg + 2.0 *BLOCK ,width_svg + 2.0 *BLOCK )),
+                    height_svg *1.1 + 2.0 *BLOCK ,width_svg + 2.0 *BLOCK )),
         false => Document::new()
                 .set("width",width_svg  )
                 .set("height",height_svg  )
-                .set("viewBox", (y_viewbox,x_viewbox,width_svg + 0.5 *BLOCK ,height_svg + 2.0 *BLOCK )),
+                .set("viewBox", (y_viewbox,x_viewbox,width_svg + 0.5 *BLOCK ,height_svg *1.1 + 2.0 *BLOCK )),
     };
     let style = Style::new(".species { font: italic ".to_owned()
         + &config.species_police_size.to_string()+"px serif; fill: "
@@ -450,7 +468,7 @@ pub fn draw_sptree_gntrees (
                                         gene_color.to_string(),
                                         free_opacity.to_string(),
                                         config.bezier.to_string().parse::<f32>().unwrap(),
-                                        0)
+                                        3)
                                 }
                             }
                         },
@@ -734,19 +752,21 @@ pub fn get_chemin_transfer (x1: f32, y1:f32,x2: f32, y2:f32, c:String, o:String,
     let controle_x = (x1 + x2) / 2.0 ;
     let controle_y = (y1 + y2) / 2.0 - bez_y ;
     // ligne horizontale
-    let data = "M".to_owned() + &x1.to_string() +" " + &initial_y1.to_string()
+    let mut data = "M".to_owned() + &x1.to_string() +" " + &initial_y1.to_string()
              +" L "+ &x1.to_string() + " " + &y1.to_string();
-    // fleche
-    let data = data.to_owned()+ "M" + &x1.to_string() + " "
+    // fleche : pas de fleche si stroke = 3
+    if stroke != 3 {
+        data = data.to_owned()+ "M" + &x1.to_string() + " "
               + &(initial_y1- PIPEBLOCK / 4.0).to_string() + "L "
               + &(x1 - PIPEBLOCK / 4.0 ).to_string() + " "
               + &(initial_y1 - PIPEBLOCK / 2.0 ).to_string();
-    let data = data.to_owned()+ "M"+&x1.to_string() + " "
+        data = data.to_owned()+ "M"+&x1.to_string() + " "
                + &(initial_y1- PIPEBLOCK / 4.0).to_string() + "L "
                + &(x1 + PIPEBLOCK / 4.0 ).to_string() + " "
                + &(initial_y1 - PIPEBLOCK / 2.0 ).to_string();
+    }
     // bezier
-    let data = data.to_owned() + "M" + &x1.to_string() + " " + &y1.to_string()
+    data = data.to_owned() + "M" + &x1.to_string() + " " + &y1.to_string()
                + " Q " + &controle_x.to_string() + " " + &controle_y.to_string()
                + " " + &x2.to_string() + " " + &y2.to_string();
     let path = Path::new()
@@ -754,7 +774,9 @@ pub fn get_chemin_transfer (x1: f32, y1:f32,x2: f32, y2:f32, c:String, o:String,
     .set("stroke", c)
     .set("opacity", o)
     .set("stroke-width", GTHICKNESS);
+    // choix du pointille
     let path = match stroke {
+        3 => path,
         2 => path.set("stroke-dasharray","4, 1"),
         1 => path.set("stroke-dasharray","1, 1"),
         0 => path,
